@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs-def.h,v 1.7 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: curs-def.h,v 1.9 2009/01/04 00:24:51 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CURS_DEF_H
@@ -174,11 +174,11 @@
 
 /**/
 
-#if	! HAVE_LIBCURSES
+#if	(! HAVE_NCURSES_H) && (! HAVE_CURSES_H)
 typedef struct {
 	int	n;
 } WINDOW;
-#endif	/* ! HAVE_LIBCURSES */
+#endif	/* (! HAVE_NCURSES_H) && (! HAVE_CURSES_H) */
 
 EXTERN WINDOW	*stdscr;
 
