@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.79 2008/09/07 11:31:27 bowkenken Exp $
+* $Id: curs.c,v 1.82 2009/01/24 23:34:24 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -126,6 +126,18 @@ static curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
 
 	{ 0, N_MSG_ATTR_MBR_6,
 		COLOR_YELLOW, COLOR_BLACK, A_REVERSE, },
+
+	{ 0, N_MSG_ATTR_HEAT,
+		COLOR_RED, COLOR_BLACK, A_BOLD, },
+
+	{ 0, N_MSG_ATTR_COLD,
+		COLOR_BLUE, COLOR_BLACK, A_BOLD, },
+
+	{ 0, N_MSG_ATTR_MIND,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+
+	{ 0, N_MSG_ATTR_ACID,
+		COLOR_YELLOW, COLOR_BLACK, A_BOLD, },
 };
 
 /***************************************************************
@@ -809,8 +821,10 @@ int	curs_getch( void )
 
 	if( g_gui_key_kind != GUI_KEY_KIND_CONSOLE )
 		return call_key_get_char();
-	if( !g_flg_cui )
+	if( !g_flg_cui ){
+		sleep_msec( 10 );
 		return '\0';
+	}
 
 	c = '\0';
 
@@ -854,8 +868,10 @@ void	curs_getnstr( char *s, int len )
 {
 	static char	buf[255 + 1];
 
-	if( !g_flg_cui )
+	if( !g_flg_cui ){
+		sleep_msec( 10 );
 		return;
+	}
 
 	s[0] = '\0';
 
