@@ -156,6 +156,7 @@ long	save_crypt_tab( FILE *fp, const char *s, ... );
 long	save_crypt_str( FILE *fp, const char *s, ... );
 long	load_crypt_str( FILE *fp, char *buf, long n );
 long	load_crypt_c( FILE *fp );
+long	load_crypt_c_sub( FILE *fp );
 void	un_load_crypt_c( FILE *fp, long c );
 
 #ifdef __cplusplus
@@ -168,6 +169,8 @@ extern "C" {
 #endif
 
 bool_t	load_game_conf( void );
+void	ver_up_game_conf_1_0_15( void );
+void	ver_up_game_data_cnf_1_2_22( void );
 bool_t	load_game_conf_head( FILE *fp, ver_t *ver );
 void	load_game_conf_data_ver_1( FILE *fp, const ver_t *ver );
 bool_t	load_game_conf_parse_ver_1( FILE *fp, const ver_t *ver );
