@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.c,v 1.207 2009/05/20 02:50:03 bowkenken Exp $
+* $Id: gfile.c,v 1.208 2009/05/24 07:29:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -3507,6 +3507,17 @@ long	load_crypt_c( FILE *fp )
 {
 	long	c;
 
+	c = load_crypt_c_sub( fp );
+	if( c == '\n' )
+		inc_rc_lex_line();
+
+	return c;
+}
+
+long	load_crypt_c_sub( FILE *fp )
+{
+	long	c;
+
 	if( feof( fp ) )
 		return EOF;
 
@@ -3529,10 +3540,6 @@ long	load_crypt_c( FILE *fp )
 			}
 			c = '\n';
 		}
-		if( c == '\n' ){
-			inc_rc_lex_line();
-			c = '\n';
-		}
 	} else {
 		c = randm_crypt( c );
 		g_crypt_sum += (char)c;
