@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,18 +25,21 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.92 2008/05/18 19:24:34 bowkenken Exp $
+* $Id: item.h,v 1.100 2009/02/07 00:35:20 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	ITEM_H
 #define	ITEM_H
 
-/* ƥ */
+/***************************************************************
+* ƥ
+***************************************************************/
 
 #include	"spell.h"
 #include	"trap.h"
 
 #include	"item-kind.h"
+#include	"item-randm-art.h"
 
 /**/
 
@@ -221,6 +224,7 @@
 #define	POTION_PRICE_D	400
 #define	POTION_PRICE_E	200
 
+#define	SCROLL_PRICE_S	10000
 #define	SCROLL_PRICE_A	1000
 #define	SCROLL_PRICE_B	800
 #define	SCROLL_PRICE_C	600
@@ -292,6 +296,7 @@ typedef enum {
 	WPN_KIND_CUTLASS,
 	WPN_KIND_SHOTEL,
 	WPN_KIND_KATANA,
+	WPN_KIND_WAKIZASHI,
 /* 쥤ԥ */
 	WPN_KIND_RAPIER,
 	WPN_KIND_ESTOC,
@@ -735,6 +740,7 @@ typedef enum {
 	FOOD_KIND_STEWED_BEEF,
 	FOOD_KIND_CONSOMME,
 	FOOD_KIND_POTAGE,
+	FOOD_KIND_SOUP_OF_TURNIP,
 	FOOD_KIND_APPLE_PIE,
 	FOOD_KIND_APPLE,
 	FOOD_KIND_GRAPE,
@@ -932,7 +938,8 @@ typedef struct {
 	long	add_hit;	/* Ͻ */
 	long	add_crtcl;	/* ƥ뽤 */
 	long	add_dam;	/* ᡼ */
-	char	slayer;	/*  */
+	char	slayer;	/* ᡼ܲ (ߴݻΤθŤ) */
+	wpn_randm_art_t	randm_art[WPN_RANDM_ART_LS_MAX_N + 1];
 	flg_wpn_tab_t	flg;	/* ե饰 */
 } wpn_t;
 
@@ -941,6 +948,7 @@ typedef struct {
 	long	add_def;	/* ɸϽ */
 	long	add_crtcl;	/* ƥ뽤 */
 	long	add_ac;	/* ޡ饹 */
+	armor_randm_art_t	randm_art[ARMOR_RANDM_ART_LS_MAX_N + 1];
 } armor_t;
 
 typedef struct {
@@ -1463,6 +1471,8 @@ typedef struct item_t {
 	char	name[ITEM_NAME_MAX_LEN + 1];
 	/* ̾ */
 	char	art_name[ITEM_ART_NAME_MAX_LEN + 1];
+	/* ̾ */
+	char	alias[ITEM_NAME_MAX_LEN + 1];
 
 	/*  */
 	item_kind_t	kind;
