@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-unix.c,v 1.21 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: main-unix.c,v 1.23 2009/01/04 00:24:52 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -54,6 +54,14 @@ int	main( int argc, char **argv )
 	return EXIT_FAILURE;
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_main_unix( void )
+{
+}
+
 /***************************************************************
 * λ
 * long code : λ
