@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.105 2009/04/11 11:00:51 bowkenken Exp $
+* $Id: request.c,v 1.108 2009/05/24 07:29:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -841,6 +841,8 @@ void	set_request_dun_lev(
 
 	min_lev = labs( min_lev );
 	max_lev = labs( max_lev );
+	range_lev = labs( range_lev );
+
 	if( max_lev < min_lev ){
 		long	n;
 
@@ -1415,8 +1417,9 @@ void	set_request_msg_var_dun_lev_range(
 	request_t *req, char *buf, char *arg
 )
 {
-	static char	str_min[32 * 4 + 1], str_max[32 * 4 + 1];
-	long	max_len = 32 * 4;
+	static char	str_min[32 * CHAR_MAX_LEN_UTF_8 + 1];
+	static char	str_max[32 * CHAR_MAX_LEN_UTF_8 + 1];
+	long	max_len = 32 * CHAR_MAX_LEN_UTF_8;
 
 	if( buf == NULL )
 		return;
@@ -2034,6 +2037,8 @@ void	chk_finish_request_chr_dead( chr_t *chr )
 	chk_finish_request_exterminate( chr->mnstr_kind, 1,
 			REQUEST_KIND_EXTERMINATE, TRUE );
 
+	put_request_rare_goods( chr );
+
 	req = chr->work.request;
 	if( req == NULL )
 		return;
@@ -2042,8 +2047,6 @@ void	chk_finish_request_chr_dead( chr_t *chr )
 	case REQUEST_KIND_NULL:
 		break;
 	case REQUEST_KIND_RARE_GOODS:
-		put_request_rare_goods( chr );
-		break;
 	case REQUEST_KIND_TAME_MNSTR:
 	case REQUEST_KIND_RESCUE:
 	case REQUEST_KIND_TOUR_GUIDE:
