@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-kind.h,v 1.10 2007/06/01 01:08:53 bowkenken Exp $
+* $Id: spell-kind.h,v 1.13 2009/01/04 00:24:52 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_KIND_H
@@ -226,9 +226,9 @@ typedef enum {
 
 	SPELL_KIND_SUBSTITUTE,	/* - */
 	SPELL_KIND_BURNING_HANDS,	/* - */
-	SPELL_KIND_DUMMY_NIN_1,	/* - */
-	SPELL_KIND_DUMMY_NIN_2,	/* - */
-	SPELL_KIND_MIND_READING,	/* - */
+	SPELL_KIND_RALLY,	/* -ڽ */
+	SPELL_KIND_IRON_MAN,	/* -Ŵ */
+	SPELL_KIND_MIND_READING,	/* -߿ */
 	SPELL_KIND_NIN_MAX_N,
 /* ANC */
 	SPELL_KIND_ANC_MIN_N,
