@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.141 2009/02/19 03:42:08 bowkenken Exp $
+* $Id: tmenu.c,v 1.145 2009/05/24 03:55:25 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -52,9 +52,7 @@
 		((LS_MBR_MAX_N + LS_MBR_MAX_N_PER_PAGE - 1)\
 		/ LS_MBR_MAX_N_PER_PAGE)
 
-#define	ORDER_MILK_MAX_LEV	100
-#define	ORDER_MILK_MIN_RATE	((rate_t)10)
-#define	ORDER_MILK_MAX_RATE	((rate_t)_100_PERCENT)
+#define	ORDER_MILK_HIGH_LEV	30
 
 /**/
 
@@ -698,8 +696,6 @@ char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 
 bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item )
 {
-	long	lev;
-	rate_t	rate;
 	sex_t	sex;
 
 	if( mbr == NULL )
@@ -714,21 +710,6 @@ bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item )
 	if( item->dat.potion.kind != POTION_KIND_MILK )
 		return FALSE;
 
-	/* ФΨ */
-
-	lev = get_specialist_lev( mbr );
-	rate = ORDER_MILK_MAX_LEV - lev;
-
-	if( rate < ORDER_MILK_MIN_RATE )
-		rate = ORDER_MILK_MIN_RATE;
-	if( rate > ORDER_MILK_MAX_RATE )
-		rate = ORDER_MILK_MAX_RATE;
-
-	/* Ф뤫 */
-
-	if( !rate_randm( rate ) )
-		return FALSE;
-
 	/* Ф */
 
 	if( rate_randm( (rate_t)50 ) )
@@ -740,6 +721,20 @@ bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item )
 			MSG_WORDS_ORDER_MILK_FEMALE,
 			MSG_WORDS_ORDER_MILK_MALE );
 
+	/* ٥Υå */
+
+	if( get_specialist_lev( mbr ) < ORDER_MILK_HIGH_LEV )
+		return TRUE;
+
+	if( rate_randm( (rate_t)50 ) )
+		sex = FEMALE;
+	else
+		sex = MALE;
+
+	print_words( MSG_NPC_NAME_BAR_CUSTOMER, sex,
+			MSG_WORDS_ORDER_MILK_HIGH_LEV_FEMALE,
+			MSG_WORDS_ORDER_MILK_HIGH_LEV_MALE );
+
 	return TRUE;
 }
 
@@ -1301,6 +1296,8 @@ long	menu_shop_sale(
 	case SHOP_N_RESTAURANT:
 	case SHOP_N_TEAROOM:
 	case SHOP_N_TOBACCO:
+		print_msg( FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT,
+				MSG_NO_DEAL, item->name );
 		return 0;
 	case SHOP_N_TEMPLE:
 		asgn = get_shop_temple_item_asgn();
@@ -2267,6 +2264,8 @@ bool_t	exec_menu_new_mbr( void )
 	ls_mbr[n]->fx.prev = &(ls_mbr[n]->fx);
 	ls_mbr[n]->fx.next = &(ls_mbr[n]->fx);
 
+	call_pcg_dun_reload_all_mbr();
+
 	return TRUE;
 }
 
@@ -4415,6 +4414,7 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 	item_t	*item;
 	shop_n_t	shop_n;
 	gold_t	price;
+	long	sale_n, sale_sum;
 	long	i;
 
 	ask = exec_menu_ask( MSG_TTL_MENU_AUTO_SALE_ASK, ASK_NO, TRUE );
@@ -4429,6 +4429,8 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 
 	ls = ls_menu_auto_sale;
 
+	sale_sum = 0;
+
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		if( ls[i].path[0] == '\0' )
 			break;
@@ -4441,12 +4443,21 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 		shop_n = get_shop_deal_article( item, DEAL_KIND_SALE_ITEM );
 		price = get_price( shop_n, item, DEAL_KIND_SALE_ITEM );
 
-		menu_shop_sale( shop_n, g_sel_mbr, item,
+		sale_n = menu_shop_sale( shop_n, g_sel_mbr, item,
 				DEAL_KIND_SALE_ITEM, TRUE );
 
-		if( price > 0 )
-			add_chr_gold( g_sel_mbr, +price );
+		if( sale_n <= 0 )
+			continue;
+		if( price <= 0 )
+			continue;
+
+		add_chr_gold( g_sel_mbr, +price );
+		sale_sum += sale_n;
 	}
+
+	if( sale_sum <= 0 )
+		return NULL;
+
 	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
 
 	add_turn( NAVI_ADD_TURN_N + SHOP_ADD_TURN_N );
